# Point de fixation

Le plugin `fixation_dot` est proposé pour plus de commodités ce qui veut dire qu'il ne fait rien de plus que ce qui peut être fait avec un item `sketchpad`. Cependant il est plus pratique de l'utiliser si vous voulez simplement présenter un point de fixation central.

Les options suivantes sont disponibles :
- `Style` précise le style du point de fixation., 
- `Duration` doit être un nombre entier positif, soit pour le 'keypress' soit pour le 'mouseclick', pour attendre un intervalle spécifique en millisecondes, jusqu'à la réponse au clavier ou à la souris respectivement.
- `Foreground color` doit être un nom de couleur en anglais (e.g., 'blue') ou une valeur HTML (e.g., '#0000FF').
- `Background color` doit être un nom de couleur en anglais (e.g., 'blue') ou une valeur HTML (e.g., '#0000FF').
- Les coordonnées `X` and `Y` indiquent la position du point de fixation.
